@@ -51,10 +51,52 @@ scene->setForegroundBrush(br);
 
 moo = new Phonon::MediaObject;;
 device = new Phonon::AudioOutput;
-Phonon::createPath(moo, device);
+audioPath=Phonon::createPath(moo, device);
 
 
 
+
+//eq
+QList<Phonon::EffectDescription> effectDescriptions =
+             Phonon::BackendCapabilities::availableAudioEffects();
+foreach (Phonon::EffectDescription effectDescription, effectDescriptions)
+    {
+
+        if ((effectDescription.name() == "KEqualizer") || (effectDescription.name() == "equalizer-10bands"))
+        {
+            eqEffect = new Phonon::Effect(effectDescription);
+
+        }
+    }
+
+QVBoxLayout* vb = new QVBoxLayout(ui.frame_7);
+QHBoxLayout* lt = new QHBoxLayout;
+int min=-12,max=12;
+for (int i = 0; i < 10; ++i)
+{
+    QSlider* s = new QSlider (Qt::Vertical);
+    s->setMinimum(min);
+    s->setMaximum(max);
+    s->setMinimumHeight(180);
+    s->setValue(0);
+    connect (s, SIGNAL(valueChanged(int)), this, SLOT(sliderChanged(int)));
+    QVBoxLayout* tmpLay = new QVBoxLayout;
+    tmpLay->addWidget(s);
+    lt->addLayout(tmpLay);
+    sliders.append(s);
+}
+QCheckBox *enabled = new QCheckBox("Enable equalizer");
+enabled->setChecked(false);
+connect(enabled, SIGNAL(toggled(bool)), this, SLOT(toggleEqualizer(bool)));
+vb->addWidget(enabled);
+vb->addLayout(lt);
+QPushButton *reset = new QPushButton("Reset sliders");
+connect (reset, SIGNAL(clicked()), this, SLOT(resetAll()));
+vb->addWidget(reset);
+setLayout(vb);
+
+
+//
 slider = new Phonon::SeekSlider(ui.widget_2);
 volume=new Phonon::VolumeSlider(ui.widget_2);
 ui.verticalLayout_3->addWidget(slider);
@@ -86,6 +128,8 @@ mmenu->addAction("Quit",qApp,SLOT(quit()));
 
 
 
+connect(ui.pushButton_10,SIGNAL(clicked()),this,SLOT(pl_sf_click()));
+
 
 connect (opt,SIGNAL(accepted()),this,SLOT(load()));
           connect(metaInformationResolver, SIGNAL(stateChanged(Phonon::State,Phonon::State)), this, SLOT(metaStateChanged(Phonon::State,Phonon::State)));
@@ -106,26 +150,53 @@ connect (opt,SIGNAL(accepted()),this,SLOT(load()));
           connect (ui.pushButton_12,SIGNAL(clicked()),mmenu,SLOT(show()));
 click1();
 
-QFile file("/home/user/.tplayer-list");
-if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
 
-    return;
+
+
+
+
+
+
+//new SQLite driven engine
+// to test
+int row=-1;
+
+     db = QSqlDatabase::addDatabase("QSQLITE");
+     db.setDatabaseName("/home/user/tplayer-list");
+
+     if(db.open()){
+     QStringList dbtables = db.tables(QSql::Tables);
+             if (dbtables.contains( tr("tracks"),
+                                    Qt::CaseInsensitive)) {
+
+}else{
+
+
+    QSqlQuery sql = QSqlQuery(db);
+    sql.exec(
+                 "create table tracks ( "
+                 "  path char(255) not null unique, "
+                 "  title char(255) , "
+                 "  artist char(255) , "
+                 "  genre char(255) , "
+                 "  album char(255) , "
+                 "  year char(255)  )" );
+}
+}else{
+    QMessageBox::critical(this, QObject::tr("Database Error"),db.lastError().text());
 }
 
-
-QTextStream in(&file);
-int row = in.readLine().toLong();
-if (row==-1)return;
-int p=0;
-while (!in.atEnd()) {
-    QString line = in.readLine();
- QStringList o=line.split(QString("%1%2").arg(QChar(9)).arg(QChar(1)));
- list.insert(p++,o);
-}
-
-drawlist();
+reload();
 ui.listWidget->setCurrentRow(row);
+
+
+if (row!=-1)
  moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
+
+
+
+
+
 #ifdef Q_WS_MAEMO_5
 grabZoomKeys(true);
 #endif
@@ -139,7 +210,29 @@ scroller2->setEnabled(true);
 
 }
 
+void MainWindow::reload(){
+    QFile file("/home/user/.tplayer-list");
+         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+           currentQuery="SELECT * FROM tracks WHERE 1";
+       }else{
+           currentQuery=file.readLine();
 
+           file.close();
+       }
+
+
+QFile file2("/home/user/.tplayer-lists");
+   if (file2.open(QIODevice::ReadOnly | QIODevice::Text)){
+       while(!file2.atEnd()){
+           QString data=file2.readLine();
+           autolist.insert(data.split("|").at(0),data.split("|").at(1));
+       }
+       autolist.remove("#");
+       file2.close();
+   }
+
+       drawlist();
+}
 
 void MainWindow::keyPressEvent(QKeyEvent* event)
   {
@@ -185,6 +278,43 @@ tu.setWidget(&t);
 dg.exec();
 }
 
+
+
+void MainWindow::sliderChanged (int val){
+
+    QSlider* s = qobject_cast<QSlider*>(sender ());
+    if (s)
+    {
+        int ind = sliders.indexOf(s);
+        if (eqEffect)
+            {
+                double dval = (double)val;
+                eqEffect->setParameterValue(eqEffect->parameters()[ind], dval);
+            }
+    }
+
+}
+
+void MainWindow::resetAll (){
+       foreach (QSlider* s, sliders)
+       {
+s->setValue(0);
+       }
+}
+
+void MainWindow::toggleEqualizer(bool val)
+{
+    if (val)
+       audioPath.insertEffect(eqEffect);
+    else
+       audioPath.removeEffect (eqEffect);
+}
+
+
+
+
+
+
 void MainWindow::load(){
 
     QFile file("/home/user/.tplayerrc");
@@ -198,14 +328,14 @@ void MainWindow::load(){
 
             h.setPointSize(tyu.at(2).toLong());
             ui.listWidget->setFont(h);
-
+            namefilter=QString(tyu.at(3)).split(" ");
             if (tyu.count()>4){
 scrobler=new last(tyu.at(4),tyu.at(5));
 
 }
             else{
                 scrobler=new last("","");
-                qDebug("no last.fm");
+                
             }
 
 file.close();
@@ -217,10 +347,29 @@ file.close();
   }else{
        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
   }
+  connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+orientationChanged();
 #endif
 }
 
+void MainWindow::orientationChanged()
+{
 
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    /*if (screenGeometry.width() > screenGeometry.height())
+    {
+        //land
+        QHBoxLayout *y=new QHBoxLayout(ui.widget);
+        y->addWidget(ui.frame_3);
+        y->addWidget(ui.frame);
+    }else{
+     // port
+        QHBoxLayout *y=new QHBoxLayout(ui.widget);
+        y->addWidget(ui.frame_3);
+        y->addWidget(ui.frame);
+    }*/
+
+}
 
 void MainWindow::about(){
     QDialog *dwidget=new QDialog(0);
@@ -240,23 +389,8 @@ dwidget->exec();
 
 MainWindow::~MainWindow()
 {
-
-
-    QFile file("/home/user/.tplayer-list");
-         if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
-             return;
-
-         QTextStream out(&file);
-         int oi=ui.listWidget->currentRow();
-         if (oi==-1 && ui.listWidget->count()>0)oi=0;
-         out << QString("%1\n").arg(oi);
-         QMapIterator<int, QStringList> i(list);
-          while (i.hasNext()) {
-              i.next();
-             out<<i.value().join(QString("%1%2").arg(QChar(9)).arg(QChar(1)))<<"\n";
-          }
-        file.close();
-
+db.commit();
+db.close();
 }
 
 void MainWindow::metaStateChanged(Phonon::State newState, Phonon::State /* oldState */)
@@ -307,21 +441,35 @@ QString genre = metaData.value("GENRE");
 if (genre=="")
     genre="Unknown";
 
-list.insert(list.count(),QStringList()<< metaInformationResolver->currentSource().fileName()<<title<<artist<<genre<<album<<year);
+//list.insert(list.count(),QStringList()<< metaInformationResolver->currentSource().fileName()<<title<<artist<<genre<<album<<year);
+QSqlQuery query(db);
+QString sq="INSERT INTO tracks (path, title, artist, genre, album, year) "
+           "VALUES ("
+            "'"+metaInformationResolver->currentSource().fileName()+
+            "','"+title+
+            "','"+artist+
+            "','"+genre+
+            "','"+album+
+            "','"+year+"')";
+
+query.exec(sq);
+
+
 
 
 queue.removeAt(queue.indexOf(metaInformationResolver->currentSource().fileName()));
 if (queue.count() > 0){
-
+    ld->setWindowTitle(queue.first());
         metaInformationResolver->setCurrentSource(queue.first());
     }
 else{
-    loading->setValue(42);
+
     ld->close();
         drawlist();
     }
 
 }catch(int e){
+    qDebug(QString("Some error with code : %1").arg(e).toAscii());
 
 }
 }
@@ -329,40 +477,12 @@ else{
 
 
 void MainWindow::clear(){
-    list.clear();
-    ui.listWidget->clear();
+    db.exec("DELETE FROM tracks WHERE 1");
+    drawlist();
 }
 
 
 
-void MainWindow::shuffle(){
-
-QList<int> o;
-for (int i=0;i<list.count();i++){
-    o.append(i);
-
-}
-
-QMap<int,QStringList> list2;
-for (int i=0;o.count()>0;i++){
-    int y=rand()%o.count();
-    list2.insert(o.at(y),list.value(i));
-    o.removeAt(y);
-}
-
-
-
-
-
-
-
-list=list2;
-
-//qSort(list.begin(), list.end(), randSort);
-drawlist();
-
-}
-
 
 
 void MainWindow::next(){
@@ -589,6 +709,48 @@ scene->clear();
 }
 }
 
+void MainWindow::alistload(){
+    QAction *t=(QAction *)sender();
+currentQuery=autolist.value(t->text());
+
+QFile file("/home/user/.tplayer-list");
+     if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
+         return;
+
+
+    file.write(currentQuery.trimmed().toAscii());
+    file.close();
+
+
+drawlist();
+}
+
+void MainWindow::pl_sf_click(){
+    lmast=new lmaster();
+connect(lmast,SIGNAL(accepted()),this,SLOT(reload()));
+
+
+    tmenu=new QMenu ();
+    // autolist
+    QMapIterator<QString,QString> item(autolist);
+    while (item.hasNext()){
+        item.next();
+        tmenu->addAction(item.key(),this,SLOT(alistload()));
+    }
+
+    //
+    tmenu->addSeparator();
+    tmenu->addAction("Light master",lmast,SLOT(exec()));
+
+
+
+    tmenu->exec(QCursor::pos());
+
+
+
+
+
+}
 
 void MainWindow::pl_fn_click(){
 QMenu fh;
@@ -598,7 +760,6 @@ fh.addMenu(&add);
 fh.addMenu(&mv);
 //add.addAction("Track",this,SLOT(pl_fn_add_track()));
 add.addAction("Directory",this,SLOT(pl_fn_add_dir()));
-fh.addAction("Shuffle",this,SLOT(shuffle()));
 fh.addAction("Clear",this,SLOT(clear()));
 mv.addAction("To begin",ui.listWidget,SLOT(scrollToTop()));
 mv.addAction("To end",ui.listWidget,SLOT(scrollToBottom()));
@@ -606,9 +767,7 @@ mv.addAction("Find",this,SLOT(find()));
  fh.exec(QCursor::pos());
 }
 
-void MainWindow::pl_fn_add_track(){
 
-}
 
 void MainWindow::find(){
     bool ok;
@@ -629,54 +788,92 @@ void MainWindow::find(){
 
 void MainWindow::pl_fn_add_dir(){
     int l=0;
-    ld=new QDialog(0);
+    ld=new QDialog();
     loading=new QProgressBar(ld);
     connect(ld,SIGNAL(rejected()),this,SLOT(ch()));
-    QString d;
-    QString f=QFileDialog::getExistingDirectory(this,"Tplayer",QDesktopServices::storageLocation(QDesktopServices::MusicLocation),QFileDialog::ReadOnly);
-    if (!f.isEmpty()){
-
-        QDirIterator it(f, QDirIterator::Subdirectories);
-        while (it.hasNext()) {
-         d=it.next();
-         QFileInfo hj(d);
-          if (hj.isFile())
-              if (QStringList(QStringList()<<"mp3"<<"flack"<<"ogg").indexOf(hj.suffix().toLower())>-1){
-l++;
-                  getMeta(d);
-              }
-    }
-    }
-    loading->setMaximum(l);
-    loading->setValue(0);
-
     QHBoxLayout *iu=new QHBoxLayout(ld);
     iu->addWidget(loading);
 
 
+    QString d;
+    QString f=QFileDialog::getExistingDirectory(this,"Tplayer",QDesktopServices::storageLocation(QDesktopServices::MusicLocation),QFileDialog::ReadOnly);
+   QApplication::processEvents();
+
+    if (!f.isEmpty())
+    {
 
-    if (d!=""){
         ld->setModal(true);
-        ld->show();
-    metaInformationResolver->setCurrentSource(d);
-   }
+        ld->open();
+        loading->setMaximum(100);
+        loading->setValue(0);
+         loading->show();
+QApplication::processEvents();
+
+
+
+QDir fg(f);
+fg.setFilter(QDir::AllDirs|QDir::Files);
+fg.setNameFilters(namefilter);
+
+
+        QDirIterator it(fg, QDirIterator::Subdirectories|QDirIterator::FollowSymlinks);
+        while (it.hasNext()) {
+         d=it.next();
+
+         QFileInfo hj(d);
+         if (hj.isFile()){
+l++;
+ld->setWindowTitle(d);
+                  getMeta(d);
+                  QApplication::processEvents();
+              }
+
+    }
+    }
+
+    loading->setMaximum(l);
+    loading->setValue(0);
+
+
+
+
+    if (l>0){
+    metaInformationResolver->setCurrentSource(queue.last());
+
+    }else{
+
+    ld->close();
+
+}
 
 
 
 }
 
 void MainWindow::ch(){
-    //if (loading->value()<100)ld->show();
+    if (loading->value()<loading->maximum())ld->show();
 }
 
 void MainWindow::drawlist(){
   //  ld->accept();
     ui.listWidget->clear();
-    QMapIterator<int, QStringList> i(list);
-     while (i.hasNext()) {
-         i.next();
-         ui.listWidget->addItem(i.value().at(2)+"-"+i.value().at(1));
-     }
+list.clear();
+
+    QSqlQuery query(currentQuery,db);
+    int id=0;
+    while ( query.next() ) {
+
+        list.insert(id++,QStringList()<<
+                    query.value(0).toString()<<
+                    query.value(1).toString()<<
+                    query.value(2).toString()<<
+                    query.value(3).toString()<<
+                    query.value(4).toString()<<
+                    query.value(5).toString());
+         ui.listWidget->addItem(query.value(2).toString()+"-"+query.value(1).toString());
+
+    }
+
 }
 
 void MainWindow::getMeta(QString path){
